/*
 © 2024 SMARTYADS, LDA doing business as “TEQBLAZE”.  All rights reserved.
 You may not use this file except in compliance with the applicable license granted to you by SMARTYADS, LDA doing business as “TEQBLAZE” (the "License").
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 Specific authorizations and restrictions shall be provided for in the License.
 */

/*   Copyright 2018-2021 Prebid.org, Inc.

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */

/*
 CHANGE NOTICE: The file content was modified to rebrand the work, adapt the product for the new use case, and change the distribution license.
 The patch to the original code is available in the Appstock repository.
 All changes after applying the patch are made under the new license and copyrights mentioned at the beginning of this file.
*/

#import <Foundation/Foundation.h>

#import "TQBAdLoaderProtocol.h"
#import "TQBBidRequesterProtocol.h"

@class TQBAdUnitConfig;
@protocol AppstockServerConnectionProtocol;
@protocol TQBAdLoadFlowControllerDelegate;

NS_ASSUME_NONNULL_BEGIN

typedef BOOL(^TQBAdUnitConfigValidationBlock)(TQBAdUnitConfig *adUnitConfig, BOOL renderWithAppstock);

@interface TQBAdLoadFlowController: NSObject

/// Lock protecting the internal state of TQBAdLoadFlowController.
@property (nonatomic, strong, nonnull, readonly) NSLock *mutationLock;

/// Queue on which internal state of TQBAdLoadFlowController is mutated
@property (nonatomic, strong, nonnull, readonly) dispatch_queue_t dispatchQueue;

/// Whether the last ad loading attempt has failed and there is no current one.
/// Should only be access
@property (nonatomic, assign, readonly) BOOL hasFailedLoading;

// State: DemandReceived
@property (nonatomic, strong, nullable) TQBBidResponse *bidResponse;

- (instancetype)initWithBidRequesterFactory:(id<TQBBidRequesterProtocol> (^)(TQBAdUnitConfig *))bidRequesterFactory
                                   adLoader:(id<TQBAdLoaderProtocol>)adLoader
                               adUnitConfig:(TQBAdUnitConfig *)adUnitConfig
                                   delegate:(id<TQBAdLoadFlowControllerDelegate>)delegate
                      configValidationBlock:(TQBAdUnitConfigValidationBlock)configValidationBlock;

/// Starts new flow of loading the ad (if idle or failed) or continues previously paused flow
- (void)refresh;

/// Allows to update external state on the same serial dispatch queue as TQBAdLoadFlowController's state mutations.
/// 'mutationLock' is automatically locked before invoking the provided block, and unlocked afterwards.
- (void)enqueueGatedBlock:(nonnull dispatch_block_t)block;

@end

NS_ASSUME_NONNULL_END
