/*
 © 2024 SMARTYADS, LDA doing business as “TEQBLAZE”.  All rights reserved.
 You may not use this file except in compliance with the applicable license granted to you by SMARTYADS, LDA doing business as “TEQBLAZE” (the "License").
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 Specific authorizations and restrictions shall be provided for in the License.
 */

/*   Copyright 2018-2021 Prebid.org, Inc.

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */

/*
 CHANGE NOTICE: The file content was modified to rebrand the work, adapt the product for the new use case, and change the distribution license.
 The patch to the original code is available in the Appstock repository.
 All changes after applying the patch are made under the new license and copyrights mentioned at the beginning of this file.
*/

#import <UIKit/UIKit.h>
#import "TQBConstants.h"
#import "TQBVoidBlock.h"

@class TQBModalState;
@class TQBAdConfiguration;
@class TQBInterstitialDisplayProperties;

typedef void (^TQBModalStatePopHandler)(TQBModalState * _Nullable poppedState);
typedef void (^TQBModalStateAppLeavingHandler)(TQBModalState * _Nullable leavingState);

@interface TQBModalState: NSObject

@property (nonatomic, strong, nullable, readonly) TQBAdConfiguration *adConfiguration;
@property (nonatomic, strong, nullable, readonly) TQBInterstitialDisplayProperties *displayProperties;
@property (nonatomic, strong, nullable, readonly) UIView *view;

@property (nonatomic, copy, nonnull) TQBMRAIDState mraidState;

@property (nonatomic, copy, nullable, readonly) TQBModalStatePopHandler onStatePopFinished;
@property (nonatomic, copy, nullable, readonly) TQBModalStateAppLeavingHandler onStateHasLeftApp;

// Used to transfer delegate function to another object, rather then current delegate for next states pushed on top
// ref: MOBILE-5849
@property (nonatomic, copy, nullable, readonly) TQBModalStatePopHandler nextOnStatePopFinished;
@property (nonatomic, copy, nullable, readonly) TQBModalStateAppLeavingHandler nextOnStateHasLeftApp;

@property (nonatomic, strong, nullable) TQBVoidBlock onModalPushedBlock;

@property (nonatomic, assign, readonly, getter=isRotationEnabled) BOOL rotationEnabled;

- (nonnull instancetype)init NS_UNAVAILABLE;

+ (nonnull instancetype)modalStateWithView:(nonnull UIView *)view
                           adConfiguration:(nullable TQBAdConfiguration *)adConfiguration
                         displayProperties:(nullable TQBInterstitialDisplayProperties *)displayProperties
                        onStatePopFinished:(nullable TQBModalStatePopHandler)onStatePopFinished
                         onStateHasLeftApp:(nullable TQBModalStateAppLeavingHandler)onStateHasLeftApp;


+ (nonnull instancetype)modalStateWithView:(nonnull UIView *)view
                           adConfiguration:(nullable TQBAdConfiguration *)adConfiguration
                         displayProperties:(nullable TQBInterstitialDisplayProperties *)displayProperties
                        onStatePopFinished:(nullable TQBModalStatePopHandler)onStatePopFinished
                         onStateHasLeftApp:(nullable TQBModalStateAppLeavingHandler)onStateHasLeftApp
                    nextOnStatePopFinished:(nullable TQBModalStatePopHandler)nextOnStatePopFinished
                     nextOnStateHasLeftApp:(nullable TQBModalStateAppLeavingHandler)nextOnStateHasLeftApp;


+ (nonnull instancetype)modalStateWithView:(nonnull UIView *)view
                           adConfiguration:(nullable TQBAdConfiguration *)adConfiguration
                         displayProperties:(nullable TQBInterstitialDisplayProperties *)displayProperties
                        onStatePopFinished:(nullable TQBModalStatePopHandler)onStatePopFinished
                         onStateHasLeftApp:(nullable TQBModalStateAppLeavingHandler)onStateHasLeftApp
                        onModalPushedBlock:(nullable TQBVoidBlock)onModalPushedBlock;

+ (nonnull instancetype)modalStateWithView:(nonnull UIView *)view
                           adConfiguration:(nullable TQBAdConfiguration *)adConfiguration
                         displayProperties:(nullable TQBInterstitialDisplayProperties *)displayProperties
                        onStatePopFinished:(nullable TQBModalStatePopHandler)onStatePopFinished
                         onStateHasLeftApp:(nullable TQBModalStateAppLeavingHandler)onStateHasLeftApp
                    nextOnStatePopFinished:(nullable TQBModalStatePopHandler)nextOnStatePopFinished
                     nextOnStateHasLeftApp:(nullable TQBModalStateAppLeavingHandler)nextOnStateHasLeftApp
                        onModalPushedBlock:(nullable TQBVoidBlock)onModalPushedBlock;

@end
